@@ -2,6 +2,8 @@ from collections import Counter, OrderedDict, defaultdict
 from typing import Counter as CounterT, Dict, Iterable, Iterator, Mapping, \
     Optional, Sequence, Set
 
+from tqdm import tqdm
+
 from .samples import FieldName, FieldValue, Sample
 
 
@@ -53,6 +55,7 @@ class Vocab(Mapping[FieldName, Mapping[str, int]]):
     def from_samples(
             cls,
             samples: Iterable[Sample],
+            pbar: Optional[tqdm] = None,
             options: Optional[Mapping[FieldName, dict]] = None,
     ) -> 'Vocab':
         """Make an instance of this class from an iterable of samples.
@@ -63,6 +66,8 @@ class Vocab(Mapping[FieldName, Mapping[str, int]]):
 
         Args:
             samples (~typing.Iterable[Sample]): Iterable of samples.
+            pbar: Instance of `tqdm <https://pypi.org/project/tqdm>`_ for displaying
+                a progress bar.
             options: Mapping from field names to dictionaries to control the creation of
                 the str-to-int mapping. Recognized dictionary keys are:
 
@@ -87,6 +92,8 @@ class Vocab(Mapping[FieldName, Mapping[str, int]]):
         Returns:
             Vocab: Vocabulary instance.
         """
+        if pbar is None:  # pragma: no cover
+            pbar = tqdm(samples, desc='Counting', unit='sample')
         if options is None:
             options = {}
 
@@ -98,6 +105,8 @@ class Vocab(Mapping[FieldName, Mapping[str, int]]):
                     counter[name].update(cls._flatten(value))
                 if isinstance(value, Sequence) and not isinstance(value, str):
                     seqfield.add(name)
+            pbar.update()
+        pbar.close()
 
         m = {}
         for name, c in counter.items():
